#include "image.h"

static char *i_format_list[]={
#ifdef HAVE_LIBJPEG
  "jpeg",
#endif
#ifdef HAVE_LIBPNG
  "png",
#endif
#ifdef HAVE_LIBGIF
  "gif",
#endif
#ifdef HAVE_LIBT1
  "t1",
#endif
#ifdef HAVE_LIBTT
  "tt",
#endif
  "raw",
  "ppm",
  NULL};

